@@ -5,7 +5,8 @@ use Carp;
 use WWW::Mechanize;
 use WWW::Mechanize::FormFiller;
 use HTTP::Cookies;
-use base qw( Term::Shell Exporter );
+use parent qw( Term::Shell );
+use Exporter 'import';
 use FindBin;
 use File::Temp qw(tempfile);
 use URI::URL;
@@ -15,7 +16,7 @@ use HTML::TokeParser::Simple;
 use B::Deparse;
 
 use vars qw( $VERSION @EXPORT %munge_map );
-$VERSION = '0.49';
+$VERSION = '0.51';
 @EXPORT = qw( &shell );
 
 =head1 NAME
@@ -2036,6 +2037,16 @@ invocation of the shell like with CPAN :
 
   perl -MWWW::Mechanize::Shell -e"shell"
 
+=head1 REPOSITORY
+
+The public repository of this module is 
+L<http://github.com/Corion/WWW-Mechanize-Shell>.
+
+=head1 SUPPORT
+
+The public support forum of this module is
+L<http://perlmonks.org/>.
+
 =head1 COPYRIGHT AND LICENSE
 
 This library is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
